Authors
=======

This file contains the list of people involved in the development
of pytest_sauce along its history.

* Grzegorz Śliwiński
* Jarosław Śmiejczak
* Paweł Wilczyński
* Krzysztof Trębicki

Great thanks to `Clearcode <http://clearcode.cc>`_ for allowing releasing pytest_sauce as free software!
